@@ -1,5 +1,5 @@
 CV.Poisson <-
-function(SampleSize=30,D=0,M=1,alpha=0.05){
+function(SampleSize,D=0,M=1,alpha=0.05){
 T<- SampleSize
 L<- T
 # ------------------- INPUT VARIABLE ----------------------------------------------------------
@@ -12,8 +12,75 @@ L<- T
 Late<- D
 MinCases<- M
 
-data(TableCV.PoissonD)
-data(TableCV.PoissonM)
+##### SOME PRE-CALCULATED CV's TO SAVE EXECUTION TIME, GIVEN M, T, ALPHA=0.05, AND D=0.
+
+TableCV.PoissonM<-data.frame(matrix(c(2.85393700326128,2.36663822744395,1.7742178463146,0,0,0,0
+,2.96497144429574,2.57638960908667,2.15070686609869,1.68320857573985,0,0,0
+,3.0469774628286,2.68935364101625,2.34967932492501,2.00015758807598,0,0,0
+,3.11041922987987,2.77748334336629,2.47487306554246,2.18732770846946,0,0,0
+,3.16210581650405,2.8493269885449,2.56531970873171,2.31713928988974,1.76648463065627,0,0
+,3.24500386808042,2.93740985148835,2.69918199672857,2.49889219887528,2.08947296098257,1.56463589358817,0
+,3.29718279728549,3.01290868171239,2.80395477091307,2.62366847225542,2.26759506082247,1.93644717718729,0
+,3.34272874946839,3.08209924178235,2.87390384946275,2.69934978606631,2.40680950082531,2.09383466767681,1.74055087831132
+,3.41378224992083,3.17006191246864,2.98556046816797,2.82925856210701,2.57262664682324,2.33777083613016,2.08603188356668
+,3.46795158033368,3.23800870652229,3.06424796686384,2.92156132978567,2.69058633468102,2.4848340056375,2.2814406139523
+,3.51174870474631,3.29055057983813,3.12525250048283,2.99310550216978,2.7814346207046,2.58938849090246,2.41540178483103
+,3.56259057516111,3.35326528420839,3.19995342291952,3.07561262580597,2.87793940574268,2.71199552491449,2.55663428340283
+,3.62812301587201,3.4301407625587,3.28821566346814,3.17637032177521,2.99779165442139,2.84685765103372,2.71713745193818
+,3.67631995875227,3.48796061486674,3.3566769512246,3.24963354903075,3.0810513452118,2.94727030411798,2.82771061367823
+,3.71576438223103,3.53415028882636,3.40671487050728,3.3071350801791,3.14780120177428,3.01963940268373,2.91122208653942
+,3.77466349620378,3.60505631658695,3.48595979980634,3.39197395348475,3.24661941308076,3.13049529955633,3.03073524477903
+,3.81990269391777,3.65714243579444,3.54482617261637,3.4555214311217,3.31795545593698,3.21042821525469,3.11755331874543
+,3.85575466209975,3.69888480478571,3.59056669774142,3.50521969535492,3.37419401277773,3.27148598919451,3.18419630429743
+,3.91085346466642,3.7624739866046,3.65993869307721,3.58089967455607,3.45808683624598,3.36288832681964,3.28403027659113
+,3.95232090599911,3.81014086931301,3.71199319899898,3.63650814981748,3.52008147061398,3.43006496056302,3.35579446678864
+,3.98557719058308,3.84774767167223,3.75332945022298,3.68058354716942,3.56867928724568,3.48296604520948,3.41123480524391
+,4.02533791597334,3.89271466068751,3.80241164747275,3.73238627490875,3.62614993442272,3.54430757139021,3.4766545706701
+,4.07482766406364,3.94892970910266,3.86276222895003,3.79683534705039,3.69651138482233,3.61982463789605,3.55679903763937
+,4.11223437028032,3.990901126178,3.90806497513453,3.84484673513135,3.74875734849489,3.67570325845673,3.61551308623033
+,4.14213356396756,4.02415316719417,3.94413519839946,3.88271021939305,3.79014311617218,3.71945215752241,3.66182960350214
+,4.18803098306215,4.07529664413041,3.99894986501106,3.94056304984504,3.85265830465641,3.78592974865935,3.73152355787215
+,4.22263170622893,4.11369239777545,4.04002057942574,3.98377804171546,3.899238807548,3.83526454689286,3.78312575686608
+,4.25030952971488,4.1443167419865,4.07263799414012,4.01808951759544,3.93617480815424,3.87418262220993,3.82390844776879
+,4.29282949701916,4.19116679996068,4.12255869710559,4.07046611590226,3.9922717187982,3.93336365702725,3.88559998964833
+,4.32491732176988,4.22641197548099,4.16002223662034,4.10966536848407,4.03421016321423,3.97745325368572,3.93152895644531),ncol=7,byrow=T))
+
+###### END TABLE
+
+##### SOME PRE-CALCULATED CV's TO SAVE EXECUTION TIME, GIVEN D, T, ALPHA=0.05, AND M=1.
+
+TableCV.PoissonD<-data.frame(matrix(c(0,0,0,0,0,0,0,0
+,2.964971,1.683209,0,0,0,0,0,0
+,3.046977,2.000158,0,0,0,0,0,0
+,3.110419,2.187328,1.600544,0,0,0,0,0
+,3.162106,2.317139,1.766485,0,0,0,0,0
+,3.245004,2.498892,2.089473,1.84232,0,0,0,0
+,3.297183,2.545178,2.267595,1.936447,1.611553,0,0,0
+,3.342729,2.546307,2.40681,2.093835,1.921859,0,0,0
+,3.413782,2.694074,2.572627,2.337771,2.211199,1.829011,0,0
+,3.467952,2.799333,2.591675,2.484834,2.298373,2.087405,1.834621,0
+,3.511749,2.88072,2.683713,2.589388,2.415402,2.254018,1.96566,1.755455
+,3.562591,2.970411,2.794546,2.711996,2.556634,2.347591,2.203782,2.020681
+,3.628123,3.082511,2.918988,2.846635,2.717137,2.542045,2.425671,2.260811
+,3.67632,3.15949,3.011001,2.886783,2.827711,2.668487,2.527763,2.432668
+,3.715764,3.223172,3.080629,2.963485,2.911222,2.765594,2.634068,2.553373
+,3.774663,3.313966,3.186878,3.078748,3.030735,2.903286,2.789967,2.68473
+,3.819903,3.381606,3.261665,3.162197,3.117553,2.99958,2.897811,2.802863
+,3.855755,3.434748,3.320749,3.226113,3.162908,3.05147,2.978063,2.890933
+,3.910853,3.515052,3.407923,3.321868,3.247872,3.15182,3.090356,3.019184
+,3.952321,3.574091,3.47261,3.391376,3.321971,3.232345,3.155596,3.109251
+,3.985577,3.620223,3.523446,3.445695,3.379278,3.294843,3.222053,3.177847
+,4.025338,3.675035,3.583195,3.509028,3.446674,3.367227,3.298671,3.238461
+,4.074828,3.742844,3.655984,3.587079,3.528662,3.454679,3.391821,3.336012
+,4.112234,3.792978,3.710128,3.644349,3.588871,3.518954,3.459256,3.406929
+,4.142134,3.832686,3.752749,3.689355,3.636272,3.568952,3.512138,3.462111
+,4.222632,3.938105,3.835265,3.808087,3.760123,3.700033,3.649189,3.605012
+,4.25031,3.97371,3.874183,3.847892,3.801678,3.743656,3.694832,3.652326
+,4.292829,4.028089,3.933364,3.887512,3.864597,3.809685,3.763627,3.723608
+,4.324917,4.047191,3.977453,3.931529,3.911308,3.858669,3.814122,3.776275),ncol=8,byrow=T))
+
+###### END TABLE
+
 
 colnames(TableCV.PoissonD)<- c(0,1,2,3,4,6,8,10)
 colnames(TableCV.PoissonM)<- c(1,2,3,4,6,8,10)
